(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('jquery')) :
    typeof define === 'function' && define.amd ? define(['jquery'], factory) :
    (global.OnoffCanvas = factory(global.jQuery));
}(this, (function ($) { 'use strict';

    $ = $ && $.hasOwnProperty('default') ? $['default'] : $;

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */

    var __assign = function() {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };

    var NAME = "onoffcanvas";
    var ClassName = {
        SHOW: "is-open"
    };
    var Selector = {
        DATA_TOGGLE: '[data-toggle="onoffcanvas"]'
    };
    var OcOption = {
        createDrawer: true,
        hideByEsc: true
    };

    function getSelectorFromElement(element) {
        var selector = element.getAttribute("data-target");
        if (!selector || selector === "#") {
            selector = element.getAttribute("href") || "";
        }
        try {
            var $selector = document.querySelectorAll(selector);
            return $selector.length > 0 ? selector : null;
        }
        catch (error) {
            throw new Error("Target Not Found!");
        }
    }

    var JQUERY_NO_CONFLICT = $.fn[NAME];
    /** @internal */
    var OnoffCanvas = /** @class */ (function () {
        function OnoffCanvas(element, config) {
            this.element = element;
            this.config = __assign({}, OcOption, (typeof config === "object" && config ? config : {}));
            this.triggerElements = $.makeArray(document.querySelectorAll(Selector.DATA_TOGGLE + "[href=\"#" + element.id + "\"]," +
                (Selector.DATA_TOGGLE + "[data-target=\"#" + element.id + "\"]")));
            var triggers = [].slice.call(document.querySelectorAll(Selector.DATA_TOGGLE));
            for (var i = 0, len = triggers.length; i < len; i++) {
                var elem = triggers[i];
                var selector = getSelectorFromElement(elem);
                var filterElement = [].slice
                    .call(document.querySelectorAll(selector))
                    .filter(function (foundElem) { return foundElem === element; });
                if (selector !== null && filterElement.length > 0) {
                    this.$selector = selector;
                    this.triggerElements.push(elem);
                }
            }
            this.addAriaExpanded(triggers);
            this.toggle();
        }
        OnoffCanvas.prototype.toggle = function () {
            if ($(this.element).hasClass(ClassName.SHOW)) {
                this.hide();
            }
            else {
                this.show();
            }
        };
        OnoffCanvas.prototype.show = function () {
            if ($(this.element).hasClass(ClassName.SHOW)) {
                return;
            }
            $(this.element).addClass(ClassName.SHOW);
            this.addAriaExpanded(this.triggerElements);
        };
        OnoffCanvas.prototype.hide = function () {
            if (!$(this.element).hasClass(ClassName.SHOW)) {
                return;
            }
            $(this.element).removeClass(ClassName.SHOW);
            this.addAriaExpanded(this.triggerElements);
        };
        /** @internal */
        OnoffCanvas.prototype.addAriaExpanded = function (triggerElements) {
            var isOpen = $(this.element).hasClass(ClassName.SHOW);
            $(triggerElements).attr("aria-expanded", isOpen ? "true" : "false");
        };
        // tslint:disable-next-line:member-ordering
        OnoffCanvas.JQI = function (config) {
            return this.each(function () {
                var $this = $(this);
                var data = $(this).data(NAME);
                var conf = __assign({}, OcOption, $this.data(), (typeof config === "object" && config ? config : {}));
                if (!data) {
                    data = new OnoffCanvas(this, conf);
                    $this.data(NAME, data);
                }
                if (typeof config === "string") {
                    if (typeof data[config] === "undefined") {
                        throw new TypeError("No method named \"" + config + "\"");
                    }
                    data[config]();
                }
            });
        };
        return OnoffCanvas;
    }());
    $(document).on("click.onoffcanvas.data-api", Selector.DATA_TOGGLE, function (event) {
        event.preventDefault();
        var $trigger = $(this);
        var selector = getSelectorFromElement(this);
        var selectors = [].slice.call(document.querySelectorAll(selector));
        $(selectors).each(function () {
            var $target = $(this);
            var data = $target.data(NAME);
            var config = data ? "toggle" : $trigger.data();
            OnoffCanvas.JQI.call($target, config);
        });
    });
    $.fn[NAME] = OnoffCanvas.JQI;
    $.fn[NAME].Constructor = OnoffCanvas;
    $.fn[NAME].noConflict = function () {
        $.fn[NAME] = JQUERY_NO_CONFLICT;
        return OnoffCanvas.JQI;
    };

    return OnoffCanvas;

})));
//# sourceMappingURL=onoffcanvas.js.map
