"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var core_1 = require("@onoffcanvas/core");
var jquery_1 = tslib_1.__importDefault(require("jquery"));
var JQUERY_NO_CONFLICT = jquery_1.default.fn[core_1.NAME];
/** @internal */
var OnoffCanvas = /** @class */ (function () {
    function OnoffCanvas(element, config) {
        this.element = element;
        this.config = tslib_1.__assign({}, core_1.OcOption, (typeof config === "object" && config ? config : {}));
        this.triggerElements = jquery_1.default.makeArray(document.querySelectorAll(core_1.Selector.DATA_TOGGLE + "[href=\"#" + element.id + "\"]," +
            (core_1.Selector.DATA_TOGGLE + "[data-target=\"#" + element.id + "\"]")));
        var triggers = [].slice.call(document.querySelectorAll(core_1.Selector.DATA_TOGGLE));
        for (var i = 0, len = triggers.length; i < len; i++) {
            var elem = triggers[i];
            var selector = core_1.getSelectorFromElement(elem);
            var filterElement = [].slice
                .call(document.querySelectorAll(selector))
                .filter(function (foundElem) { return foundElem === element; });
            if (selector !== null && filterElement.length > 0) {
                this.$selector = selector;
                this.triggerElements.push(elem);
            }
        }
        this.addAriaExpanded(triggers);
        this.toggle();
    }
    OnoffCanvas.prototype.toggle = function () {
        if (jquery_1.default(this.element).hasClass(core_1.ClassName.SHOW)) {
            this.hide();
        }
        else {
            this.show();
        }
    };
    OnoffCanvas.prototype.show = function () {
        if (jquery_1.default(this.element).hasClass(core_1.ClassName.SHOW)) {
            return;
        }
        jquery_1.default(this.element).addClass(core_1.ClassName.SHOW);
        this.addAriaExpanded(this.triggerElements);
    };
    OnoffCanvas.prototype.hide = function () {
        if (!jquery_1.default(this.element).hasClass(core_1.ClassName.SHOW)) {
            return;
        }
        jquery_1.default(this.element).removeClass(core_1.ClassName.SHOW);
        this.addAriaExpanded(this.triggerElements);
    };
    /** @internal */
    OnoffCanvas.prototype.addAriaExpanded = function (triggerElements) {
        var isOpen = jquery_1.default(this.element).hasClass(core_1.ClassName.SHOW);
        jquery_1.default(triggerElements).attr("aria-expanded", isOpen ? "true" : "false");
    };
    // tslint:disable-next-line:member-ordering
    OnoffCanvas.JQI = function (config) {
        return this.each(function () {
            var $this = jquery_1.default(this);
            var data = jquery_1.default(this).data(core_1.NAME);
            var conf = tslib_1.__assign({}, core_1.OcOption, $this.data(), (typeof config === "object" && config ? config : {}));
            if (!data) {
                data = new OnoffCanvas(this, conf);
                $this.data(core_1.NAME, data);
            }
            if (typeof config === "string") {
                if (typeof data[config] === "undefined") {
                    throw new TypeError("No method named \"" + config + "\"");
                }
                data[config]();
            }
        });
    };
    return OnoffCanvas;
}());
jquery_1.default(document).on("click.onoffcanvas.data-api", core_1.Selector.DATA_TOGGLE, function (event) {
    event.preventDefault();
    var $trigger = jquery_1.default(this);
    var selector = core_1.getSelectorFromElement(this);
    var selectors = [].slice.call(document.querySelectorAll(selector));
    jquery_1.default(selectors).each(function () {
        var $target = jquery_1.default(this);
        var data = $target.data(core_1.NAME);
        var config = data ? "toggle" : $trigger.data();
        OnoffCanvas.JQI.call($target, config);
    });
});
jquery_1.default.fn[core_1.NAME] = OnoffCanvas.JQI;
jquery_1.default.fn[core_1.NAME].Constructor = OnoffCanvas;
jquery_1.default.fn[core_1.NAME].noConflict = function () {
    jquery_1.default.fn[core_1.NAME] = JQUERY_NO_CONFLICT;
    return OnoffCanvas.JQI;
};
/** @internal */
exports.default = OnoffCanvas;
